@ECHO off

REM
REM This script will create a new directory, NewProjectDirectory, and copy the contents of a template directory, 
REM   ProjectTemplateDirectory, into the new project and rename several files and strings within those files to create a
REM   a new project from the template.  Since this template is creating a project using the TurtleBrains framework the
REM   latest TurtleBrains source and External Libraries will be pulled from source control.
REM
REM <!-- Copyright (c) 2015 Tim Beaudet - All Rights Reserved -->
REM -------------------------------------------------------------------------------------------------------------------

SETLOCAL enabledelayedexpansion

REM Set variables for running the TemplateProject creation script.
SET CurrentDirectory=%CD%

SET /P NewProjectName=ProjectDisplayName:
SET /P NewProjectFile=project_file_name:
REM SET /P NewProjectDate=Date MM/DD/YYYY:
SET NewProjectDate="05/16/2015"

SET NewProjectDir="%CurrentDirectory%\%NewProjectFile%"
REM SET ProjectTemplateDir="C:\Dev\Personal\Undefined\template_turtle_brains"
SET ProjectTemplateDir="\\hippo\shelter\development\undefined\template_projects\template_turtle_brains"

REM Protection in case the TemplateProjectDirector does not exist, or creating a NewProjectDirectory that does exist.
IF NOT EXIST "%ProjectTemplateDir%" (ECHO ProjectTemplate Directory was not found)&GOTO :eof
IF EXIST "%NewProjectDir%" (ECHO Project Directory already exists...)&GOTO :eof

ECHO Copying template directory structure and files %NewProjectDir%.
REM /Y Copy without confirming replacement of existing files.
REM /E Copies any subdirectories, even if they are empty.
REM /S Copies directories and subdirectories unless they are empty. (/E copies empty).
REM /H Copies hidden and system files too.
REM /K Copies attributes (read-only).
REM /R Overwrite read-only files, if they were there.
REM > NUL throws the output into nothing so it the prompt remains clean.
XCOPY %ProjectTemplateDir% %NewProjectDir%\ /Y /E /S /H /K /R > NUL

ECHO Renaming the template parameters to %NewProjectName%
REM Find and replace "TEMPLATE_PROJECT_DATE" / "TEMPLATE_PROJECT_NAME" / "TEMPLATE_PROJECT_FILE" accordingly.

RENAME "%NewProjectDir%\source\TEMPLATE_PROJECT_NAME.h" "%NewProjectFile%.h"
RENAME "%NewProjectDir%\source\TEMPLATE_PROJECT_NAME.cpp" "%NewProjectFile%.cpp"
FOR /R "%NewProjectDir%" %%f in (*.h;*.cpp;*.bat;*.sh;*.txt) do (
  sed -i "s|TEMPLATE_PROJECT_DATE|%NewProjectDate%|g" %%f
  sed -i "s|TEMPLATE_PROJECT_FILE|%NewProjectFile%|g" %%f
  sed -i "s|TEMPLATE_PROJECT_NAME|%NewProjectName%|g" %%f
  sed -i "s|template_turtle_brains|%NewProjectName%|g" %%f
)

ECHO Pulling latest TurtleBrains source and externals into project.
svn checkout --quiet "http://www.timbeaudet.com/turtlebrains/source" "%NewProjectDir%\source\turtle_brains"
svn checkout --quiet "http://www.timbeaudet.com/turtlebrains/external_libraries" "%NewProjectDir%\build\tb_external_libraries"

REM REM SVN SVN SVN SVN SVN SVN SVN SVN SVN SVN SVN SVN SVN SVN SVN SVN
REM REM See if the user wants to add this project to a subversion repository.
REM SET /P SetupSubVersion=Do you want to setup Subversion? (Y/N)
REM IF NOT %SetupSubVersion% == y IF NOT %SetupSubVersion% == Y GOTO NoSubversion
REM 
REM SET svnpath=%NewProjectDir%/
REM CALL projecttosvn
REM REM SVN SVN SVN SVN SVN SVN SVN SVN SVN SVN SVN SVN SVN SVN SVN SVN
REM 
REM :NoSubVersion

ECHO Build the Debug and Release configurations of the %NewProjectName% project.
CD "%NewProjectDir%\build\automated"
CALL auto_build.bat
CD "%CurrentDirectory%"

ECHO Enjoy working on the %NewProjectName% project.
