#!/bin/sh

#
# This script will create a new directory, NewProjectDirectory, and copy the contents of a template directory, 
#   ProjectTemplateDirectory, into the new project and rename several files and strings within those files to create a
#   a new project from the template.  Since this template is creating a project using the TurtleBrains framework the
#   latest TurtleBrains source and External Libraries will be pulled from source control.
#
# <!-- Copyright (c) 2015 Tim Beaudet - All Rights Reserved -->
#---------------------------------------------------------------------------------------------------------------------#

#Set variables for running the TemplateProject creation script.
export CurrentDirectory=$(pwd)

read -e -p "ProjectDisplayName: " NewProjectName
read -e -p "project_file_name: " NewProjectFile
#read -e -p "Date MM/DD/YYYY: " NewProjectDate
export NewProjectDate="05/16/2015"

export NewProjectDir="$CurrentDirectory/$NewProjectFile"
#export ProjectTemplateDir=$HOME/Documents/dev/undefined/template_turtle_brains/
export ProjectTemplateDir="${HOME}/../../Volumes/shelter/development/undefined/template_projects/template_turtle_brains/"
 
#Protection in case the TemplateProjectDirector does not exist, or creating a NewProjectDirectory that does exist.
if [ ! -d "$ProjectTemplateDir" ]; then
    echo Template Project Directory was not found, are you connected to server in Finder?
    exit
fi
if [ -d "$NewProjectDir" ]; then
    echo Project Directory already exists...
    exit
fi

echo Copying template directory structure and files $NewProjectDir.
# -r copies recursively
cp -r "$ProjectTemplateDir" "$NewProjectDir"

echo Renaming the template parameters to $NewProjectName
#Find and replace "TEMPLATE_PROJECT_DATE" / "TEMPLATE_PROJECT_NAME" / "TEMPLATE_PROJECT_FILE" accordingly.

mv "$NewProjectDir/source/TEMPLATE_PROJECT_NAME.h" "$NewProjectDir/source/$NewProjectFile.h"
mv "$NewProjectDir/source/TEMPLATE_PROJECT_NAME.cpp" "$NewProjectDir/source/$NewProjectFile.cpp"
for file in $(find "$NewProjectDir" -name '*.h' -or -name '*.cpp' -or -name '*.bat' -or -name '*.sh' -or -name '*txt'); do
    sed -i '.bak' "s|TEMPLATE_PROJECT_DATE|$NewProjectDate|g" "$file"
    sed -i '.bak' "s|TEMPLATE_PROJECT_FILE|$NewProjectFile|g" "$file"
    sed -i '.bak' "s|TEMPLATE_PROJECT_NAME|$NewProjectName|g" "$file"
    sed -i '.bak' "s|template_turtle_brains|$NewProjectName|g" "$file"

    rm "$file.bak"
done

echo Pulling latest TurtleBrains source and externals into project.
svn checkout --quiet "http://www.timbeaudet.com/turtlebrains/source/" "$NewProjectDir/source/turtle_brains"
svn checkout --quiet "http://www.timbeaudet.com/turtlebrains/external_libraries/" "$NewProjectDir/build/tb_external_libraries"

# REM SVN SVN SVN SVN SVN SVN SVN SVN SVN SVN SVN SVN SVN SVN SVN SVN
# REM See if the user wants to add this project to a subversion repository.
# SET /P SetupSubVersion=Do you want to setup Subversion? (Y/N)
# IF NOT %SetupSubVersion% == y IF NOT %SetupSubVersion% == Y GOTO NoSubversion
#
# SET svnpath=%NewProjectDir%/
# CALL projecttosvn
# REM SVN SVN SVN SVN SVN SVN SVN SVN SVN SVN SVN SVN SVN SVN SVN SVN
#
# :NoSubVersion

echo Build the Debug and Release configurations of the $NewProjectName project.
cd "$NewProjectDir/build/automated"
sh auto_build.sh
cd "$CurrentDirectory"
 
echo Enjoy working on the $NewProjectName project.
